@@ -1,5 +1,5 @@
 """AMQP Messaging Framework for Python"""
-VERSION = (1, 0, 5)
+VERSION = (1, 0, 6)
 __version__ = ".".join(map(str, VERSION[0:3])) + "".join(VERSION[3:])
 __author__ = "Ask Solem"
 __contact__ = "ask@celeryproject.org"
@@ -57,3 +57,8 @@ if not os.environ.get("KOMBU_NO_EVAL", False):
         "__homepage__": __homepage__,
         "__docformat__": __docformat__,
         "VERSION": VERSION})
+
+if os.environ.get("KOMBU_LOG_DEBUG"):
+    os.environ["KOMBU_LOG_CHANNEL"] = "1"
+    from kombu.utils import debug
+    debug.setup_logging()
